pub enum OwnerCheck {
FirstUse,
Match,
Mismatch,
}Expand description
The verdict of comparing an authenticated account against a library’s owner.
Variants
FirstUse
The library is not pinned yet, so it can be adopted (trust-on-first-use).
Match
The authenticated account owns this library.
Mismatch
The authenticated account differs from the pinned owner.