pub fn source_statuses(
areas: &[AreaListing],
force_copy: bool,
) -> Vec<SourceStatus>Expand description
The per-source enumeration status of every area, for the deletion verdict.
pub fn source_statuses(
areas: &[AreaListing],
force_copy: bool,
) -> Vec<SourceStatus>The per-source enumeration status of every area, for the deletion verdict.