pub struct FsError { /* private fields */ }Expand description
A filesystem failure, carrying a kind and a human-readable, secret-free reason.
Implementations
Sourceimpl FsError
impl FsError
Sourcepub fn new(reason: impl Into<String>) -> Self
pub fn new(reason: impl Into<String>) -> Self
Build an FsError of kind FsErrorKind::Other from any displayable
cause.
Sourcepub fn out_of_space(reason: impl Into<String>) -> Self
pub fn out_of_space(reason: impl Into<String>) -> Self
Build an out-of-space FsError (kind FsErrorKind::OutOfSpace).
Sourcepub fn kind(&self) -> FsErrorKind
pub fn kind(&self) -> FsErrorKind
The failure kind.
Sourcepub fn is_out_of_space(&self) -> bool
pub fn is_out_of_space(&self) -> bool
Whether this failure was a full disk or exhausted quota.